declare const onPermissionsAccepted: Window['onPermissionsAccepted'];
declare const onPaymentStatusChanged: Window['onPaymentStatusChanged'];
/**
 * The Ayoba native interface calls this method every time
 * the app receives a new location event.
 *
 * Remember this listener will only be called when the native
 * permission is accepted by the user.
 *
 * In some border cases, also can receive lat=0.0, lon=0.0. Most of
 * the cases, will mean Ayoba cannot retrieve the GPS coordinates.
 */
declare function onLocationChanged(lat: number, lon: number): void;
/**
 * The Ayoba native interface calls this method every time
 * the user presence changes (infact, always online)
 */
declare function onPresenceChanged(presence: string): void;
/** In Chat Context the nickname and avatar calls are a single function. **/
declare function onProfileChanged(nickname: string, avatar: string): void;
/** In Discovery (Apps) Context the nickname and avatar calls are separated in two functions. **/
/** Calls this method every time the user avatar changes **/
declare function onAvatarChanged(avatar: string): void;
/** Calls this method every time the user nickname changes **/
declare function onNicknameChanged(nickname: string): void;
/**
 * This method should be implemented to retrieve the "sendMedia(...)" result
 *
 * @param {int} responseCode: result code
 *  0: the location could not be sent
 *  1: the location has been sent successfully
 * @param encodedUrl: Base64 encoded media file’s url
 */
declare function onMediaSentResponse(responseCode: number, encodedUrl: string): void;
/**
 * This method should be implemented to retrieve the "sendLocation(...)" result
 *
 * @param {int} responseCode: result code
 *  0: the location could not be sent
 *  1: the location has been sent successfully
 */
declare function onLocationSentResponse(responseCode: number): void;
export { onAvatarChanged, onLocationChanged, onLocationSentResponse, onMediaSentResponse, onNicknameChanged, onPaymentStatusChanged, onPermissionsAccepted, onPresenceChanged, onProfileChanged, };
