"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.onProfileChanged = exports.onPresenceChanged = exports.onPermissionsAccepted = exports.onPaymentStatusChanged = exports.onNicknameChanged = exports.onMediaSentResponse = exports.onLocationSentResponse = exports.onLocationChanged = exports.onAvatarChanged = void 0;
function dispatchCustomEvent(eventName, payload) {
    var event = new CustomEvent(eventName, { detail: payload });
    document.dispatchEvent(event);
}
// Ayoba Events
var onPermissionsAccepted = function (paymentMethods) {
    dispatchCustomEvent('onPermissionsAccepted', { paymentMethods: paymentMethods });
};
exports.onPermissionsAccepted = onPermissionsAccepted;
var onPaymentStatusChanged = function (transactionId, status, error) {
    console.log('jhjkhjhjkhjhk', { transactionId: transactionId, status: status, error: error });
    dispatchCustomEvent('onPaymentStatusChanged', { transactionId: transactionId, status: status, error: error });
};
exports.onPaymentStatusChanged = onPaymentStatusChanged;
/**
 * The Ayoba native interface calls this method every time
 * the app receives a new location event.
 *
 * Remember this listener will only be called when the native
 * permission is accepted by the user.
 *
 * In some border cases, also can receive lat=0.0, lon=0.0. Most of
 * the cases, will mean Ayoba cannot retrieve the GPS coordinates.
 */
function onLocationChanged(lat, lon) {
    dispatchCustomEvent('onLocationChanged', { lat: lat, lon: lon });
}
exports.onLocationChanged = onLocationChanged;
/**
 * The Ayoba native interface calls this method every time
 * the user presence changes (infact, always online)
 */
function onPresenceChanged(presence) {
    dispatchCustomEvent('onPresenceChanged', { presence: presence });
}
exports.onPresenceChanged = onPresenceChanged;
/** In Chat Context the nickname and avatar calls are a single function. **/
function onProfileChanged(nickname, avatar) {
    dispatchCustomEvent('onProfileChanged', { nickname: nickname, avatar: avatar });
}
exports.onProfileChanged = onProfileChanged;
/** In Discovery (Apps) Context the nickname and avatar calls are separated in two functions. **/
/** Calls this method every time the user avatar changes **/
function onAvatarChanged(avatar) {
    dispatchCustomEvent('onAvatarChanged', { avatar: avatar });
}
exports.onAvatarChanged = onAvatarChanged;
/** Calls this method every time the user nickname changes **/
function onNicknameChanged(nickname) {
    dispatchCustomEvent('onNicknameChanged', { nickname: nickname });
}
exports.onNicknameChanged = onNicknameChanged;
/**
 * This method should be implemented to retrieve the "sendMedia(...)" result
 *
 * @param {int} responseCode: result code
 *  0: the location could not be sent
 *  1: the location has been sent successfully
 * @param encodedUrl: Base64 encoded media file’s url
 */
function onMediaSentResponse(responseCode, encodedUrl) {
    dispatchCustomEvent('onMediaSentResponse', { responseCode: responseCode, encodedUrl: encodedUrl });
}
exports.onMediaSentResponse = onMediaSentResponse;
/**
 * This method should be implemented to retrieve the "sendLocation(...)" result
 *
 * @param {int} responseCode: result code
 *  0: the location could not be sent
 *  1: the location has been sent successfully
 */
function onLocationSentResponse(responseCode) {
    dispatchCustomEvent('onLocationSentResponse', { responseCode: responseCode });
}
exports.onLocationSentResponse = onLocationSentResponse;
/**
 * This method should be implemented to retrieve the "sendFileRetrievedResponse(...)" result
 *
 * @param {int} responseCode: result code
 *  -1: the file could not be retrieved
 *  1: the file has retrieved successfully
 * @param {String} filePath: user selected files paths array
 */
function onFileRetrievedResponse(responseCode, filePath) {
    dispatchCustomEvent('onFileRetrievedResponse', { responseCode: responseCode, filePath: filePath });
}
/**
 * This method should be implemented to retrieve the "sendPicture(...)" result
 *
 * @param {int} responseCode: result code
 *  0: the picture could not be taken
 *  1: the picture has been taken successfully
 */
function onPictureRetrievedResponse(responseCode, picturePath) {
    dispatchCustomEvent('onPictureRetrievedResponse', { responseCode: responseCode, picturePath: picturePath });
}
